@@ -34,7 +34,7 @@ class DemoModelField(models.Model):
 class DemoRelated(models.Model):
     name = models.CharField(max_length=255)
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
 
 
@@ -48,6 +48,9 @@ class DemoModel(models.Model):
     class Meta:
         app_label = 'demoapp'
 
+    def __str__(self):
+        return self.name
+
 
 class DemoModel2(models.Model):
     name = models.CharField(max_length=255)
