@@ -1,4 +1,4 @@
-import django.contrib.admin
+# import django.contrib.admin
 import django.contrib.admin.sites
 from django.conf.urls import url
 from django.contrib.auth.models import User
@@ -15,14 +15,14 @@ class PublicAdminSite(django.contrib.admin.sites.AdminSite):
 
 public_site = PublicAdminSite()
 django.contrib.admin.autodiscover()
-public_site.register(models.DemoModel_RelatedFieldCheckBoxFilter,
-                     admin.DemoModelAdmin_RelatedFieldCheckBoxFilter)
-public_site.register(models.DemoModel_RelatedFieldRadioFilter,
-                     admin.DemoModelAdmin_RelatedFieldRadioFilter)
-public_site.register(models.DemoModel_UnionFieldListFilter,
-                     admin.DemoModelAdmin_UnionFieldListFilter)
-public_site.register(models.DemoModel_IntersectionFieldListFilter,
-                     admin.DemoModelAdmin_IntersectionFieldListFilter)
+# public_site.register(models.DemoModel_RelatedFieldCheckBoxFilter,
+#                      admin.DemoModelAdmin_RelatedFieldCheckBoxFilter)
+# public_site.register(models.DemoModel_RelatedFieldRadioFilter,
+#                      admin.DemoModelAdmin_RelatedFieldRadioFilter)
+# public_site.register(models.DemoModel_UnionFieldListFilter,
+#                      admin.DemoModelAdmin_UnionFieldListFilter)
+# public_site.register(models.DemoModel_IntersectionFieldListFilter,
+#                      admin.DemoModelAdmin_IntersectionFieldListFilter)
 public_site.register(models.DemoRelated, admin.DemoRelatedModelAdmin)
 public_site.register(models.DemoModel, admin.DemoModelModelAdmin)
 public_site.register(User, admin.IUserAdmin)
